Refactor PUSCH RE mapping

RE mapping time is reduced by 10x. Functions are made generic to be
later reused for PDSCH RE mapping at gNB.
This commit is contained in:
Sakthivel Velumani
2024-09-03 09:21:29 +02:00
committed by francescomani
parent add341e2f1
commit 393363e253
6 changed files with 500 additions and 178 deletions
-11
View File
@@ -1421,17 +1421,6 @@ int main(int argc, char *argv[])
errors_decoding++;
}
}
if (n_trials == 1) {
for (int r = 0; r < UE->ul_harq_processes[harq_pid].C; r++)
for (int i = 0; i < UE->ul_harq_processes[harq_pid].K >> 3; i++) {
if ((UE->ul_harq_processes[harq_pid].c[r][i] ^ ulsch_gNB->harq_process->c[r][i]) != 0)
printf("************");
/*printf("r %d: in[%d] %x, out[%d] %x (%x)\n",r,
i,UE->ul_harq_processes[harq_pid].c[r][i],
i,ulsch_gNB->harq_process->c[r][i],
UE->ul_harq_processes[harq_pid].c[r][i]^ulsch_gNB->harq_process->c[r][i]);*/
}
}
if (errors_decoding > 0 && error_flag == 0) {
n_false_positive++;
if (n_trials==1)